#
# spec file for package shairport-sync
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           shairport-sync
Version:        4.1.1
Release:        bp155.1.6
Summary:        An AirPlay audio player
License:        GPL-3.0-only
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://github.com/mikebrady/shairport-sync
Source0:        https://github.com/mikebrady/shairport-sync/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        airplay-server.xml
Source2:        README.SUSE
# PATCH-FIX-OPENSUSE drop-user-config.patch hillwood@opensuse.org -- Move configuring user account to rpm spec.
# Move configuring user account to rpm spec.
Patch0:         drop-user-config.patch
Patch1:         harden_shairport-sync.service.patch
BuildRequires:  fdupes
BuildRequires:  firewall-macros
BuildRequires:  gcc-c++
BuildRequires:  gnome-common
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(avahi-client)
BuildRequires:  pkgconfig(libconfig)
BuildRequires:  pkgconfig(libdaemon)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(popt)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(soxr)
BuildRequires:  pkgconfig(systemd)
Requires:       firewalld
Requires(pre):  shadow
%{?systemd_ordering}

%description
Shairport Sync is an AirPlay audio player – it plays audio streamed from iTunes,
iOS, Apple TV and macOS devices and AirPlay sources such as Quicktime Player and
ForkedDaapd, among others.

Audio played by a Shairport Sync-powered device stays synchronised with the
source and hence with similar devices playing the same source. In this way,
synchronised multi-room audio is possible for players that support it, such as
iTunes.

Shairport Sync runs on Linux, FreeBSD and OpenBSD. It does not support AirPlay
video or photo streaming.

%prep
%setup -q
%patch0 -p1
cp %{SOURCE2} .
%patch1 -p1

%build
autoreconf -i -f
%configure --with-systemd \
           --with-ssl=openssl \
           --with-pa \
           --with-pipe \
           --with-avahi \
           --with-soxr \
           --with-metadata \
           --with-configfiles \
           --with-convolution
%make_build

%install
%make_install
mkdir -p %{buildroot}%{_prefix}/lib/firewalld/services
install -m 0644 %{SOURCE1} %{buildroot}%{_prefix}/lib/firewalld/services/
rm %{buildroot}%{_sysconfdir}/shairport-sync.conf.sample
mkdir -p %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

%pre
getent group %{name} >/dev/null || %{_sbindir}/groupadd --system %{name}
getent passwd %{name} >/dev/null || %{_sbindir}/useradd --system -c "%{name} User" \
        -d %{_localstatedir}/%{name} -m -g %{name} -s %{_sbindir}/nologin \
        -G audio %{name}
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service
%firewalld_reload

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%doc README.md RELEASENOTES.md TROUBLESHOOTING.md README.SUSE
%license LICENSES
%config(noreplace) %{_sysconfdir}/shairport-sync.conf
%{_bindir}/%{name}
%dir %{_prefix}/lib/firewalld
%dir %{_prefix}/lib/firewalld/services
%{_prefix}/lib/firewalld/services/airplay-server.xml
%{_mandir}/man7/shairport-sync.7%{?ext_man}
%{_unitdir}/%{name}.service
%{_sbindir}/rc%{name}

%changelog
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 4.1.1:
  * This release consists of enhancements and bug fixes to Version 4.1. For
    information on the new features of 4.1, including AirPlay 2 support,
    please refer to the 4.1 Release Note.
  Enhancements
  * Use the TCP keepalive facility to close a play session if the client
    connection drops for a minute.
  Metadata Enhancements
  * Add FramePosition (phbt), FirstFramePosition (phb0), OutputRate (ofps),
    OutputFormat (ofmt), StreamType (styp), ServiceName (svna), ClientName
    (snam) properties to the D-Bus interface and to the metadata stream
    (codes in brackets).
  * FramePosition/FirstFramePosition metadata is generated only if the
    progress_interval in the metadata section of the configuration file is
    non-zero. The progress interval can also be set by a new
    SetFramePositionUpdateInterval method in the D-Bus interface.
  * FramePosition/FirstFramePosition metadata is of the form <RTP Frame
    number>/<Local Time> where the local time, in nanoseconds (a 64-bit
    number), is the precise time that frame should be played. The metadata
    is generated when the frame is placed in the output buffer, and is thus
    generated audio_backend_buffer_desired_length_in_seconds (usually 0.2
    seconds) before the time in question.
  * Add xesam:albumArtist and xesam:composer metadata (if available) to the
    metadata bundle presented in the D-Bus interface.
  * Add a new metadata item: sps:songdatakind, derived from the asdk
    metadata token, to the metadata bundle presented in the D-Bus interface.
    If 0 it seems to indicate an item of a specific duration such as an
    audio track; if 1 it seems to mean the stream is of unknown duration,
    for example an internet radio stream.
  Bug Fixes
  * Fix a bug that prevented multiple classic AirPlay instances being
    recognised. The bug was that the 12-digit classic AirPlay service name
    prefixes for each instance were all identically derived from a MAC
    hardware address. The fix was to modify the generation of  prefixes to
    depend on the service name as well as the hardware address.
  * Fix a bug that prevented play to the the PulseAudio backend from
    resuming after a pause. The bug was due to changes in the way pauses
    were handled and the fix was to reopen the stream if it is closed
    whenever a play or latency request was made.
  * Fix a long-standing bug which didn't close the socket used for the RTSP
    connection, potentially exhausting the sockets available.
  * Fix a bug in audio_alsa.c when there is no hardware device name.
  * Add a configuration check for the xxd program when building for AirPlay
    2.
  * Fix a compilation bug on certain platforms by trying to use AC_CHECK_LIB
    to find libavcodec if the PKG_CHECK_MODULES check fails.
* Tue Dec 27 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 4.1
  * AirPlay 2 support
  * Improved libao backend for better compatibility with HomeBrew installations
  * Improved MQTT and D-Bus facilities
  * Metadata improvements
  * Automatically-generated Docker images
* Mon Feb  7 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.3.9
  * Fix a build failure with convolution raised since automake 1.16.5
    and https://git.savannah.gnu.org/cgit/automake.git/commit/?id=f4a3a70f69e1dbccb6578f39ef47835098a04624
  * Fix tinysvcmdns: rr_data_len goes beyond packet buffer
* Wed Nov 17 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_shairport-sync.service.patch
* Wed Aug 18 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.3.8
  * For the PulseAudio backend pa, added a new server entry to the pa section of
    the configuration file, allowing you to specify a connection to a remote or
    a local system PulseAudio instance instead of letting PulseAudio choose.
  * Enhance features. See details in RELEASENOTES.md
  * Fix bugs
* Wed Aug 19 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Mon Mar 23 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.3.6
  * Resampling has been added for the Jack Audio backend. This can be
    used to up-sample to 192kHz.
  * Fix bugs. Please refer to
    https://github.com/mikebrady/shairport-sync/blob/master/RELEASENOTES.md#version-336
* Sun Jan 19 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.3.5
  * Fix a crashing bug if output format S24 was chosen.
  * Fix a bug whereby if Loudness was enabled through the D-Bus interface, the
    output would be muted until the volume was changed.
  * Enhancements to the D-Bus Interface
  * Fixes a deferred crash that occurred in Ubuntu 14.04
  * Fixes a potential crash when an incomplete fmtp parameter set is sent by the
    requesting client. Thanks to Angus71 for the fault report and for the
    repair.
  * Fixed a potential crash
  * A fix ensures the hardware mixer of an alsa device is detected and
    initialised before responding to the first volume setting.
  * Fixes were made to the MPRIS and native D-Bus interfaces.
  * Fixes an error whereby the 'pvol'volume metadata was no longer sent if
    Shairport Sync was configured to ignore volume control information coming
    from the audio source.
  * Instead of returning EXIT_FAILURE, return EXIT_WITH_SUCCESS on early exit
    with either "version" (–version or -V) or "help" (–help or -h) arguments.
    Thanks to Henrik Nilsson for the patch.
  * Normalises the 'pvol' volume outputs so that when both the software and
    hardware attenuators are in use to extend the overall attenuation range, the
    maximum output level corresponds to the maximum output level of the hardware
    mixer.
  * Add the option of including the file and line number of each log entry's
    source.
  * Rewrite the logic for identifying missing packets of audio and for asking
    for resends.
  * Expose the advanced settings controlling the resend request logic.
  * Exposes two advanced metadata settings related to handling cover art
* Tue Oct 22 2019 Tuukka Pasanen <tuukka.pasanen@ilmi.fi>
- Update version to 3.3.2
- Bug Fixes
  * Fix a bug that sometimes caused a crash when a service name was
    specified in the configuration file. The fix was to be more
    systematic in allocating and deallocating memory for temporary strings.
    Thanks to Chris Boot, Ari Sovijarvi, Bernhard Übelacker and
    Jeroen Massar for the bug report. Fixes Debian Bug report #925577
    and supercedes Pull Request #879.
  * Correct some documentation typos – thanks again to Chris Boot.
- Enhancements
  * Add some settings for controlling the disable_standby_mode.
  * The first setting is the disable_standby_mode_silence_threshold,
    which is the amount of audio in the output device's hardware buffer.
    It should normally be close to the value given in the
    audio_backend_buffer_desired_length_in_seconds setting.
    If it drops to this value, silence is added to the buffer to prevent
    the output device from becoming idle.
  * The second new setting is the disable_standby_mode_silence_scan_interval
    which is the time between checks of the output device's hardware buffer.
* Mon Jun 24 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.3.1
  * Fix a bug in the MQTT documentation and add sanity checking for the port
    chosen -- thanks to David Crook.
  * Fix a bug that caused manual format and rate settings to be ignored --
    thanks to Jörg Krause.
  * Add missing support for format settings S24_LE, S24_BE, S32_LE and S32_BE.
  * Fix a bug that caused dither to be too loud.
  * Fix error message for invalid
  * Automatic Format and Speed Selection for alsa devices. Using the alsa back
    end, when you specify the output device, Shairport Sync will now, by
    default, select the best output format and speed. For instance, if your
    output device is capable of 32-bit operation, it will be selected. In some
    situations, this will give a noticeable improvement in sound quality – see
    the discussion of audio improvements below. The greatest bit depth will
    always be selected, and the lowest speed that is a multiple of 44,100.
  * Audio Transient Reduction: A Disable Standby feature to eliminate certain
    faint-but-annoying audible pops and clicks has been added for alsa devices.
    The setting prevents an output device entering standby mode and thus
    minimises standby/busy transitions, which can sometimes be heard. It is
    pretty impressive, especially combined with fixes to the dithering code
    described below. If you can enable 24- or 32-bit audio output to your output
    device, you can get even better results. This feature is available in the
    ALSA back end (standard in Linux) when it is driving output devices that can
    provide precision delay information, i.e. most hardware output devices and
    possibly some virtual devices.
  * New active/inactive program hooks. Basically, these are "deglitched"
    replacements for play start/play end program hooks. When a play session
    starts, the system goes active. When the play session ends, the system
    remains active for a period determined by the active_state_timeout setting,
    10 seconds by default. If another play session starts before the period
    elapses, the system stays active; otherwise the system goes inactive. The
    hooks are performed when the system goes active or inactive.
  * A new MQTT client interface, with support for metadata and for some remote
    control commands.
  * A new Jack Audio back end.
  * PulseAudio: A new option for the pa backend to allow the specification of
    the audio sink.
  * CYGWIN: An updated and enhanced installation procedure to install Shairport
    Sync as a Cygwin service.
  * Opt-in default for certain added features: If support for soxr, metadata or
    the Apple ALAC decoder is included during building (i.e. at the ./configure
    stage), then the features are enabled by default at run time. The features
    are (1) soxr interpolation – chosen automatically if the device is fast
    enough, (2) the Apple ALAC decoder and (3) metadata, which is implied when
    you include support for metadata, D-Bus, MPRIS or MQTT features.
  * Shairport Sync can now receive AirPlay streams consisting of raw PCM – 16
    bit stereo frames at 44,100 samples per second. Packets must be 352 frames
    exactly.
  * Improved support for big-endian CPUs by adding support for explicit -endian
    formats, i.e. S16_LE, S16_BE, S24_LE, S24_BE, S32_LE, S32_BE.
  * Add a list of alsa hardware devices found to the alsa backend help section
    in the shairport-sync -h text. (Linux only – doesn't work on
    FreeBSD/OpenBSD.)
  * Replace the existing watchdog, which only offered partial coverage, with a
    much more robust thread-based watchdog.
  * Allow a reported remote processing time of zero.
  * Fix a logical error that could cause an endless loop during a flush.
  * Ensure a player thread is correctly initialised before allowing it to be
    cancelled cleanly.
  * Ensure the player thread always has a cancellation point so that it should
    always be possible to ask it to terminate.
  * If a play session is interrupted, wait for it to terminate for up to three
    seconds.
  * If a play session is interrupted, ensure the new session uses a different
    set of UDP ports. This is to ensure that data from the interrupted session –
    which might be still in transit – doesn't enter the new session.
  * Make all ALSA command sequences un-cancellable. This is to ensure that ALSA
    subsystem will not be left in a partially-initialised state if Shairport
    Sync terminates abruptly.
  * When a connection is terminated abruptly, ensure that all the UDP ports is
    use are closed properly.
  * Impose timeouts on both reading and writing to the supervisory RTSP
    connection governing a session.
  * When closing the RTSP connection due to an error, close it immediately,
    without waiting for a full TCP handshake, because, if the other end has
    erred, the handshake may never come.
  * Fix a parameter initialisation error in a situation where there is no
    hardware mixer.
  * Fix an MQTT-related crash by ignoring unrecognised commands.
  * Fix a compilation error and a warning when using the --with-convolution
    configuration option.
  * A compilation problem in OpenBSD has been fixed by changing the order of
    some include files.
  * Fix a problem when calling the program to be run when the volume control is
    changed. Thanks to shaven for the report.
  * Remove unrecognised options from FreeBSD and OpenBSD compilation
    instructions.
  * Ensure the compiler flag HAVE_LIBSOXR is defined if the --with-soxr
    configuration flag is used and pkg-config is in use.
  * Fix a bug in the dbus native interface which would silently switch soxr
    interpolation to basic.
  * Fix a mutex lock bug in the metadata hub. No known effects.
  * Fix an arithmetic overflow in frame rate calculations that could occur after
    2^32 frames – approximately 27 hours at 44,100 frames per second.
  * A number of memory leaks have been identified and removed.
  * An incorrect warning about using the deprecated general statistics options
    has been fixed.
* Mon Mar 18 2019 Jan Engelhardt <jengelh@inai.de>
- Transform bash-specific sh code to POSIX sh in scriptlets.
- Do not hide errors from useradd.
- Reduce hard scriptlet dependency on systemd;
  %%service_* does not need it.
* Sun Feb 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Really use upstream tarball from the source url
* Wed Feb  6 2019 Tuukka Pasanen <tuukka.pasanen@ilmi.fi>
- Update to release 3.2.2
  Version 3.2 introduces two big new features – MPRIS support and a "native" Shairport
  Sync D-Bus interface. MPRIS offers a standard set of facilities for implementing remote
  control and the native D-Bus interface allows local programs to interact
  directly with Shairport Sync.
  When used with either of these interfaces, Shairport Sync offers access
  to the remote control commands available to control the source, and also
  offers access to metadata, including titles and cover art. These new features
  are experimental, but are already useful.
  This release of Shairport Sync contains important bug fixes and stability
  improvements and is recommended for all users. If offers better synchronisation,
  better compatibility with third-party AirPlay sources, greater stability when
  used with YouTube and macOS system sound, faster resynchronisation, better
  performance on noisy or congested networks and many other improvements.
  A quick INSTALL guide for the Raspberry Pi, a how-to CAR INSTALL guide and
  a note about installing to OpenBSD have been added.
- See https://github.com/mikebrady/shairport-sync/releases for details
* Mon Jul 30 2018 jengelh@inai.de
- Avoid repeating name in summary (rpmlint).
* Mon Jun 11 2018 hillwood@opensuse.org
- Initial package for 3.2rc10.
- Add drop-user-config.patch, move configuring user account to rpm spec.
- Add firewalld profile.
- Add README.SUSE
